@@ -27,7 +27,10 @@ class TestObjectBase():
         for prop in testobject:
             if(prop in testobject):
                 setattr(self, prop, testobject[prop])
-        self.customProperties = resource["customProperties"]
+        if "customProperties" in resource:
+            self.customProperties = resource["customProperties"]
+        else:
+            self.customProperties = {}
         self.session = session
         self.name = name
         self.robot = session.robot
